import os
import xml.etree.ElementTree as ET
from sqlalchemy import create_engine, Column, String, MetaData, Table, text
from sqlalchemy.orm import sessionmaker
from pathlib import Path
import argparse
from sqlalchemy.dialects.mysql import insert

# Define the SQLAlchemy model
metadata = MetaData()


def define_table(data_type):
    existing_table = metadata.tables.get(data_type)
    if existing_table is not None:
        return existing_table

    return Table(
        data_type,
        metadata,
        Column('id', String(length=255), primary_key=True),
        Column('str', String(length=255, collation='utf8mb4_unicode_ci')),
        Column('imagePath', String(
            length=255, collation='utf8mb4_unicode_ci'), nullable=True),
        Column('sortName', String(
            length=255, collation='utf8mb4_unicode_ci'), nullable=True),
        Column('category', String(
            length=255, collation='utf8mb4_unicode_ci'), nullable=True),
        Column('netOpenName', String(
            length=255, collation='utf8mb4_unicode_ci'), nullable=True),
        Column('rareType', String(
            length=255, collation='utf8mb4_unicode_ci'), nullable=True),
        mysql_charset='utf8mb4',
        mysql_collate='utf8mb4_unicode_ci'
    )


def parse_xml(file_path):
    tree = ET.parse(file_path)
    return tree.getroot()


def find_data(root, data_type):
    id_element = root.find('.//name/id')
    str_element = root.find('.//name/str')

    data = {'id': id_element.text, 'str': str_element.text}

    if data_type == "cozynet_chuni_static_accessory":
        data.update({
            'imagePath': root.find('.//image/path').text or "",
            'sortName': root.find('.//sortName').text or "",
            'category': root.find('.//category').text or "",
            'netOpenName': root.find('.//netOpenName/str').text or ""
        })

    elif data_type in ["cozynet_chuni_static_nameplate"]:
        data.update({
            'imagePath': root.find('.//image/path').text or "",
            'sortName': root.find('.//sortName').text or "",
            'netOpenName': root.find('.//netOpenName/str').text or ""

        })

    elif data_type in ["cozynet_chuni_static_systemvoice"]:
        data.update({
            'imagePath': root.find('.//image/path').text or "",
            'sortName': root.find('.//sortName').text or ""
        })

    elif data_type == "cozynet_chuni_static_trophies":
        data.update({
            'rareType': root.find('.//rareType').text or "",
            'netOpenName': root.find('.//netOpenName/str').text or ""
        })

    elif data_type == "cozynet_chuni_static_mapicon":
        data.update({
            'imagePath': root.find('.//image/path').text or "",
            'sortName': root.find('.//sortName').text or ""
        })

    return data


def insert_data_into_database(session, data_type, data):
    table = define_table(data_type)
    stmt = insert(table).values(data).on_duplicate_key_update(data)
    session.execute(stmt)


def process_directories(base_path, session, data_types, xml_file_names):
    for data_type, xml_file_name in zip(data_types, xml_file_names):
        base_directories = [base_path]

        for directory in base_directories:
            for xml_path in find_xml_files(directory, xml_file_name):
                root = parse_xml(xml_path)
                data = find_data(root, data_type)
                if data:
                    insert_data_into_database(session, data_type, data)


def find_xml_files(directory, xml_file_name):
    for dirpath, _, filenames in os.walk(directory):
        if xml_file_name in filenames:
            yield Path(dirpath) / xml_file_name


def main():
    parser = argparse.ArgumentParser(
        description='Process XML files and write data to MySQL database.')
    parser.add_argument('--base_path', type=str,
                        help='Base path to the Chunithm data directory', required=True)
    parser.add_argument('--mysql_host', type=str,
                        help='MySQL host address', required=True)
    parser.add_argument('--mysql_port', type=int,
                        help='MySQL port number', required=True)
    parser.add_argument('--mysql_user', type=str,
                        help='MySQL username', required=True)
    parser.add_argument('--mysql_password', type=str,
                        help='MySQL password', required=True)
    parser.add_argument('--mysql_db', type=str,
                        help='MySQL database name', required=True)

    args = parser.parse_args()

    base_path = args.base_path
    mysql_host = args.mysql_host
    mysql_port = args.mysql_port
    mysql_user = args.mysql_user
    mysql_password = args.mysql_password
    mysql_db = args.mysql_db

    data_types = ['cozynet_chuni_static_accessory', 'cozynet_chuni_static_nameplate',
                  'cozynet_chuni_static_systemvoice', 'cozynet_chuni_static_trophies', 'cozynet_chuni_static_mapicon']
    xml_file_names = ['AvatarAccessory.xml', 'NamePlate.xml',
                      'SystemVoice.xml', 'Trophy.xml', 'MapIcon.xml']

    # Create MySQL database connection URL
    database_url = f"mysql://{mysql_user}:{mysql_password}@{mysql_host}:{mysql_port}/{mysql_db}?charset=utf8mb4"

    # Create an engine and session for the MySQL database
    engine = create_engine(database_url)
    Session = sessionmaker(bind=engine)
    session = Session()

    # Drop existing tables
    for data_type in data_types:
        table = define_table(data_type)
        table.drop(engine, checkfirst=True)

    # Create tables in the MySQL database
    for data_type in data_types:
        define_table(data_type).create(engine, checkfirst=True)

    process_directories(base_path, session, data_types, xml_file_names)

    # Commit changes and close the session
    session.commit()
    session.close()


if __name__ == "__main__":
    main()
