import os
import re
from pathlib import Path
from PIL import Image
from tqdm import tqdm
import argparse


def find_dds_files(source_folders, file_pattern=None):
    dds_files = []
    for source_folder in source_folders:
        for root, _, files in os.walk(source_folder):
            for file in files:
                if file.endswith('.dds') and (file_pattern is None or file_pattern.match(file)):
                    dds_files.append(os.path.join(root, file))
    return dds_files


def convert_dds_to_png(dds_file_path, png_file_path, scale_percent=50):
    with Image.open(dds_file_path) as img:
        new_width = int(img.width * scale_percent / 100)
        new_height = int(img.height * scale_percent / 100)
        img = img.resize((new_width, new_height), Image.Resampling.LANCZOS)
        img.save(png_file_path, 'PNG')


def process_files(files, destination_folder, progress_prefix, scale_percent=100):
    files_to_convert = []

    for file_path in files:
        file_name = os.path.splitext(os.path.basename(file_path))[0] + '.png'
        png_file_path = os.path.join(destination_folder, file_name)
        if not os.path.exists(png_file_path):
            files_to_convert.append(file_path)

    if not files_to_convert:
        print(f"{progress_prefix}: Already converted!")
        return

    for file_path in tqdm(files_to_convert, desc=progress_prefix, unit='file'):
        file_name = os.path.splitext(os.path.basename(file_path))[0] + '.png'
        png_file_path = os.path.join(destination_folder, file_name)
        convert_dds_to_png(file_path, png_file_path, scale_percent)


def process_avatarAccessory(source_folders, destination_folder, progress_prefix):
    avatar_accessory_files = find_dds_files(source_folders)

    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    process_files(avatar_accessory_files, destination_folder,
                  progress_prefix, scale_percent=50)


def process_nameplates(source_folders, destination_folder, progress_prefix):
    nameplate_files = find_dds_files(source_folders)

    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    process_files(nameplate_files, destination_folder, progress_prefix)


def process_systemVoiceImages(source_folders, destination_folder, progress_prefix):
    nameplate_files = find_dds_files(source_folders)

    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    process_files(nameplate_files, destination_folder, progress_prefix)


def process_JacketArt(source_folders, destination_folder, progress_prefix):
    nameplate_files = find_dds_files(source_folders)

    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    process_files(nameplate_files, destination_folder, progress_prefix)


def process_mapIcon(source_folders, destination_folder, progress_prefix):
    nameplate_files = find_dds_files(source_folders)

    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    process_files(nameplate_files, destination_folder, progress_prefix)


def process_partners(source_folders, destination_chunithm, destination_chusan):
    pattern_chunithm = re.compile(
        r'CHU_UI_Character_0([0-9]{3})_(00|01)_[0-9]{2}\.dds$')

    pattern_chusan = re.compile(
        r'CHU_UI_Character_([1-9]\d{3,})_(00|01)_[0-9]{2}\.dds$')

    chunithm_files = find_dds_files(source_folders, pattern_chunithm)
    chusan_files = find_dds_files(source_folders, pattern_chusan)

    if not os.path.exists(destination_chunithm):
        os.makedirs(destination_chunithm)
    process_files(chunithm_files, destination_chunithm,
                  "Chunithm Partners")

    if not os.path.exists(destination_chusan):
        os.makedirs(destination_chusan)
    process_files(chusan_files, destination_chusan,
                  "Chusan Partners")


def find_subdirectories(base_directories, subdirectory_names):
    subdirectory_paths = {name: [] for name in subdirectory_names}
    for base_directory in base_directories:
        for subdir in Path(base_directory).rglob('*'):
            if subdir.is_dir() and subdir.name in subdirectory_names:
                subdirectory_paths[subdir.name].append(str(subdir))
    return subdirectory_paths


def main(data_folder, option_folder, output_folder):
    relevant_subdirs = ['music', 'avatarAccessory',
                        'mapIcon', 'namePlate', 'ddsImage', 'systemVoice']

    subdirectories = find_subdirectories(
        [data_folder, option_folder], relevant_subdirs)

    output_path = output_folder
    if not os.path.exists(output_path):
        os.makedirs(output_path)

    process_partners(subdirectories['ddsImage'], os.path.join(
        output_path, 'public', 'chunithm_partners'), os.path.join(output_path, 'public', 'chusan_partners'))
    process_nameplates(subdirectories['namePlate'], os.path.join(
        output_path, 'public', 'namePlates'), 'namePlate')
    process_systemVoiceImages(subdirectories['systemVoice'], os.path.join(
        output_path, 'public', 'systemVoiceThumbnails'), 'systemVoice thumbnail')
    process_JacketArt(subdirectories['music'], os.path.join(
        output_path, 'public', 'JacketArt'), 'jacket art')
    process_mapIcon(subdirectories['mapIcon'], os.path.join(
        output_path, 'public', 'mapIcon'), 'map icon')
    process_avatarAccessory(subdirectories['avatarAccessory'], os.path.join(
        output_path, 'public', 'avatarAccessory'), 'avatarAccessory Progress')

    print("All conversions and transfers complete.")


if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description='Converts Chunithm dds files to pngs for CozyNet webUI.')
    parser.add_argument('data_folder', type=str, help='Path to data folder')
    parser.add_argument('option_folder', type=str,
                        help='Path to option folder')
    parser.add_argument('output_folder', type=str,
                        help='Path to the output folder')

    args = parser.parse_args()
    main(args.data_folder, args.option_folder, args.output_folder)
