"use client"

import { useRouter } from "next/navigation"
import { useState } from "react"
import axios from "axios"
import { toast, ToastContainer } from "react-toastify"
import "react-toastify/dist/ReactToastify.css"
import { FaSpinner } from "react-icons/fa"
import { z, ZodError } from "zod" // Import Zod for input validation
import Link from "next/link"
import { Input } from "@/components/ui/input"
import { ApiFetch } from "@/lib/api"

const loginSchema = z.object({
  username: z.string().min(3).max(20),
  password: z.string().min(6).max(30),
})

export default function Home() {
  const { push } = useRouter()
  const [loading, setLoading] = useState(false)

  const handleSubmit = async (event: React.FormEvent<HTMLFormElement>) => {
    event.preventDefault()

    try {
      const formValues = {
        username: event.currentTarget.username.value,
        password: event.currentTarget.password.value,
      }

      // Validate form data using Zod
      loginSchema.parse(formValues)

      setLoading(true)

      const response = await ApiFetch(
        "/SDHD/verifyUser",
        {
          method: "POST",
          body: JSON.stringify(formValues),
          headers: {
            "Content-Type": "application/json",
          },
        },
        false,
        true,
      )

      if (response.statusCode !== 200) {
        return;
      }

      toast.success("Login successful!", {
        className: "success-toast",
        bodyClassName: "toast-body",
        closeButton: false,
        theme: "colored",
      })

      push("/chunithm")
    } catch (error) {
      handleLoginError(error)
    } finally {
      setLoading(false)
    }
  }

  function handleLoginError(error: any) {
    if (error instanceof ZodError) {
      // Zod validation error
      toast.error("Invalid credentials, please try again.", {
        className: "error-toast",
        bodyClassName: "toast-body",
        closeButton: false,
        theme: "colored",
      })
    } else if (axios.isAxiosError(error)) {
      // Other Axios errors
      if (error.response && error.response.status === 404) {
        toast.error("Invalid credentials, please try again.", {
          className: "error-toast",
          bodyClassName: "toast-body",
          closeButton: false,
          theme: "colored",
        })
      }
    }
  }

  return (
    <main>
      <div className="flex min-h-screen items-center justify-center bg-background px-6">
        <div className="w-full max-w-md">
          <div className="overflow-hidden rounded-sm bg-subsectionbackgroundcolor">
            <div className="px-10 py-8">
              <div className="mb-8 text-center">
                <h1 className="text-2xl font-semibold text-typography">
                  USER LOGIN
                </h1>
              </div>
              <form onSubmit={handleSubmit} className="space-y-6">
                <div>
                  <label className="mb-2 block text-sm font-medium text-typography">
                    Username
                    <Input
                      type="text"
                      id="username"
                      name="username"
                      placeholder="Username"
                      required
                      className="mt-2 w-full rounded-md border px-4 py-2 "
                    />
                  </label>
                </div>
                <div>
                  <label className="mb-2 block text-sm font-medium text-typography ">
                    Password
                    <Input
                      type="password"
                      id="password"
                      name="password"
                      placeholder="********"
                      required
                      className="mt-2 w-full rounded-md border px-4 py-2 "
                    />
                  </label>
                </div>
                <div className="flex items-center justify-end">
                  <Link
                    href="/"
                    className="start cursor-pointer text-sm font-bold uppercase text-typography hover:underline"
                  >
                    Forgot Password?
                  </Link>
                </div>
                <div className="px-10 py-4 text-center">
                  <button
                    type="submit"
                    className="relative cursor-pointer text-sm font-bold uppercase text-typography hover:underline"
                    disabled={loading}
                  >
                    {loading && (
                      <span className="absolute left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 transform">
                        <FaSpinner className="animate-spin" />
                      </span>
                    )}
                    {!loading && "Login"}
                  </button>
                </div>
              </form>
            </div>
            <div className="px-10 py-4 text-center">
              <Link
                href="/signup"
                className="cursor-pointer text-sm font-bold uppercase text-typography hover:underline"
              >
                Create account
              </Link>
            </div>
            <ToastContainer
              position="top-center"
              autoClose={5000}
              hideProgressBar={false}
              newestOnTop={false}
              closeOnClick
              rtl={false}
              pauseOnFocusLoss
              draggable
              pauseOnHover
              limit={3}
              toastClassName="toast-class"
            />
          </div>
        </div>
      </div>

      <style jsx>{`
        .toast-class {
          background-color: #2a2a2a;
          color: white;
          border-radius: 8px;
          box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.1);
        }

        .success-toast {
          background-color: #4caf50;
        }

        .error-toast {
          background-color: #f44336;
        }

        .toast-body {
          font-size: 0.9rem;
          padding: 15px;
        }
      `}</style>
    </main>
  )
}
