// Import necessary libraries and components
"use client"
import React, { useState } from "react"
import Image from "next/image"
import { UsePlayerInfo } from "@/app/axios/useFetchApi"
import { ARTEMIS_CHUNITHM_LUMINOUS, SUPPORTED_VERSIONS } from "@/lib/constants"

interface CharacterImageProps {
  characterId: number
}

const CharacterImage = ({ characterId }: CharacterImageProps) => {
  let calculatedId = Math.floor(characterId / 10)
  const calculatedIdStr = calculatedId.toString()

  if (calculatedIdStr.length > 4) {
    calculatedId = parseInt(calculatedIdStr.slice(0, -1))
  }

  const paddedId = calculatedId.toString().padStart(4, "0")

  const baseDirectory = `${process.env.NEXT_PUBLIC_CDN}chusan_partners/CHU_UI_Character_${paddedId}_00_02.png`
  const fallbackDirectory = `${process.env.NEXT_PUBLIC_CDN}chunithm_partners/CHU_UI_Character_${paddedId}_00_02.png`

  const [imageUrl, setImageUrl] = useState(baseDirectory)
  const [attemptedFallback, setAttemptedFallback] = useState(false)
  const handleError = () => {
    if (!attemptedFallback) {
      setImageUrl(fallbackDirectory)
      setAttemptedFallback(true)
    }
  }
  return (
    <Image
      src={imageUrl}
      onError={handleError}
      alt="Character Image"
      width={64}
      height={64}
      className="absolute left-2 top-2 h-10 w-10 border-4 border-songjacketborder md:left-6 md:top-4 md:h-20 md:w-20"
    />
  )
}

// TeamInfo component
type TeamInfoProps = {
  teamName?: string
}

const TeamInfo = ({ teamName }: TeamInfoProps) => (
  <div className="font-semi absolute left-24 top-2 mt-1 rounded-sm bg-playerteambadge p-1 text-xs   font-semibold  uppercase text-characterbadgetypography md:left-28 md:top-6 md:mt-2 md:p-3">
    {teamName ? `Belongs to team ${teamName}` : "You do not belong to a team."}
  </div>
)

// CharacterCard component
const CharacterCard = () => {
  // State and effect hooks for managing player info
  const [profileData, setPlayerInfo] = useState<any[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  // Fetch player info using custom hook
  UsePlayerInfo({ setPlayerInfo, setLoading, setError })

  const isSupportedVersion = profileData.some(
    (user) => SUPPORTED_VERSIONS.includes(user.version),
  )

  if (!Array.isArray(profileData) || profileData.length === 0 || !isSupportedVersion) {
    return null // Don't render the card if version is not supported
  }

  // get the highest version of a users profile
  const highestVersion = Math.max(...profileData.map((user) => user.version))

  // Filter the profileData to include only users with the highest version
  const versionUserData = profileData.filter(
    (user) => user.version === highestVersion,
  )
  return (
    <div className="md:mx-auto md:px-0">
      {versionUserData.map((user, index) => {
        // Destructure user data
        const {
          trophyname,
          level,
          userName,
          playerRating,
          highestRating,
          overPowerRate,
          lastPlayDate,
          characterId,
          reincarnationNum,
          teamName,
        } = user
        return (
          <div
            key={index}
            className="relative mb-2 w-[395px] rounded-sm bg-cardsectionbackgroundcolor p-2  sm:w-[640px] md:w-[840px] md:p-6 lg:w-[690px] xl:w-[790px] 2xl:w-[1390px] "
          >
            <div className="flex items-center">
              <CharacterImage characterId={characterId} />
            </div>
            <TeamInfo teamName={teamName} />
            <div className="pt-14 md:pt-20">
              <div className="mb-2 ml-1 mt-2 text-xs uppercase md:-ml-1 md:text-sm">
                <span className="rounded-sm bg-playertrophybadge px-2 py-1 font-semibold text-playertrophytext">
                  {trophyname || "New comer"}
                </span>
              </div>
              <div className="mb-2 md:mb-2">
                <span className="text-xs uppercase text-typography">
                  Lv.
                  {reincarnationNum > 0 && (
                    <span className="text-xs uppercase text-typography">
                      <span className="text-lg font-bold">
                        {" "}
                        {reincarnationNum}
                        {level}
                      </span>
                    </span>
                  )}
                  {reincarnationNum < 1 && (
                    <span className="text-lg font-bold"> {level}</span>
                  )}
                </span>
                <span className="ml-2 font-bold text-typography md:ml-2 md:text-lg">
                  {userName}
                </span>
              </div>
              <div className="mb-2 md:mb-2">
                <span className="text-xs uppercase text-typography">
                  Rating
                </span>
                <div className="flex items-center">
                  <span className="mr-1 font-bold text-typography">
                    {(playerRating / 100).toFixed(2)}
                  </span>
                  <span className="ml-1 text-xs font-bold text-typography">
                    (max): {(highestRating / 100).toFixed(2)}
                  </span>
                </div>
              </div>
              <div className="mb-2 md:mb-2">
                <span className="text-xs uppercase text-typography">
                  Over Power
                </span>
                <div className="flex items-center text-typography">
                  <span className="mr-1 font-bold text-typography">
                    {(overPowerRate / 100).toFixed(2)} %
                  </span>
                </div>
              </div>
              <div className="text-xs text-typography">
                Last play date{" "}
                <span className="font-bold">
                  {lastPlayDate || "Not available"}
                </span>
              </div>
            </div>
          </div>
        )
      })}
    </div>
  )
}

export default CharacterCard
