"use client"
import React, { useEffect, useState } from "react"
import Image from "next/image"
import {
  useFetchStaticMusic,
  usePlayerFavoriteSongsList,
} from "@/app/axios/useFetchApi"
import { FaHeart } from "react-icons/fa" // Import heart icon from react-icons library
import { UsePostFavoriteSongs } from "@/app/axios/usePostApi"
import { Input } from "./ui/input"
import { JacketImageProps, songCardProps } from "@/lib/types"

const JacketImage: React.FC<JacketImageProps> = ({ jacketPath }) => (
  <Image
    src={jacketPath}
    alt="Character Image"
    width={90}
    height={90}
    className=" border-sm border-4 border-songjacketborder"
  />
)

const SongCard: React.FC<songCardProps> = ({
  title,
  artist,
  songId,
  jacketPath,
}) => {
  const { playerFavoriteSongs, refetchPlayerFavoriteSongs } =
    usePlayerFavoriteSongsList()
  const [loading, setLoading] = useState<boolean>(false)
  const [error, setError] = useState<string | null>(null)

  const isFavorite = playerFavoriteSongs.some(
    (favSong) => favSong.songId === songId
  )

  const { postFavoriteSong } = UsePostFavoriteSongs({
    onPostSuccess: (data) => {
      console.log("Favorite song posted successfully:", data)
      // Refetch player's favorite songs after a successful post
      refetchPlayerFavoriteSongs()
    },
    setLoading,
    setError,
  })

  const handleFavoriteClick = () => {
    const favoriteSongData = {
      songId,
    }

    postFavoriteSong(favoriteSongData)
  }

  const formattedJacketPath = `${process.env.NEXT_PUBLIC_CDN
    }JacketArt/${jacketPath.slice(0, -3)}png`

  return (
    <div className="flex items-center">
      <div className="flex-shrink-0">
        <JacketImage jacketPath={formattedJacketPath} />
      </div>
      <div className="ml-4">
        <span className="block font-semibold  text-typography dark:text-typography">
          {title}
        </span>
        <span className="block text-typography  dark:text-typography">
          {artist}
        </span>
      </div>
      <button className="ml-auto p-2" onClick={handleFavoriteClick}>
        <FaHeart
          className={`${isFavorite ? "text-heartcolornormal" : "text-heartcolorfave"
            }`}
          style={{ fontSize: "2em" }}
        />
      </button>
    </div>
  )
}

interface NavigationButtonsProps {
  currentPage: number
  totalPages: number
  onPageChange: (page: number) => void
  onNext: () => void
  onPrevious: () => void
}

// NavigationButtons Component
const NavigationButtons: React.FC<NavigationButtonsProps> = ({
  currentPage,
  totalPages,
  onPageChange,
  onNext,
  onPrevious,
}) => {
  // Only show a maximum of 5 page buttons around the current page
  const rangeStart = 5 * Math.floor((currentPage - 1) / 5) + 1
  const rangeEnd = Math.min(rangeStart + 4, totalPages)

  const pages = Array.from(
    { length: rangeEnd - rangeStart + 1 },
    (_, index) => rangeStart + index
  )

  return (
    <div className="flex items-center justify-center space-x-1 ">
      <button
        onClick={onPrevious}
        disabled={currentPage === 1}
        className="rounded bg-paginationbackground px-4 font-bold text-paginationtypography hover:text-paginationtypographyhover   disabled:opacity-40"
      >
        Previous
      </button>
      {pages.map((page) => (
        <button
          key={page}
          onClick={() => onPageChange(page)}
          disabled={currentPage === page}
          className={`rounded bg-paginationbackground px-2 font-bold text-paginationtypography hover:text-paginationtypographyhover ${currentPage === page ? " " : ""
            }`}
        >
          {page}
        </button>
      ))}
      <button
        onClick={onNext}
        disabled={currentPage === totalPages}
        className="rounded bg-paginationbackground px-4  font-bold text-paginationtypography hover:text-paginationtypographyhover  disabled:opacity-40"
      >
        Next
      </button>
    </div>
  )
}

const SongCardList = () => {
  const [profileData, setPlayerStaticMusic] = useState<any[]>([])
  const [loading, setLoading] = useState<boolean>(true)
  const [error, setError] = useState<string | null>(null)
  const [itemsPerPage] = useState<number>(7)
  const [currentPage, setCurrentPage] = useState<number>(1)
  const [searchQuery, setSearchQuery] = useState("")
  const [filteredData, setFilteredData] = useState<any[]>([])
  const { playerFavoriteSongs } = usePlayerFavoriteSongsList() // Use the hook

  useFetchStaticMusic({ setPlayerStaticMusic, setLoading, setError })

  useEffect(() => {
    const filtered = profileData.filter((item) => {
      const queryLower = searchQuery.toLowerCase()
      return item.title && item.title.toLowerCase().includes(queryLower)
    })
    setFilteredData(filtered)
  }, [searchQuery, profileData])

  const totalPages = Math.ceil(filteredData.length / itemsPerPage)

  const indexLastItem = currentPage * itemsPerPage
  const indexFirstItem = indexLastItem - itemsPerPage
  const currentItems = filteredData.slice(indexFirstItem, indexLastItem)

  const handleNext = () => {
    setCurrentPage((prevCurrentPage) =>
      Math.min(prevCurrentPage + 1, totalPages)
    )
  }

  const handlePrevious = () => {
    setCurrentPage((prevCurrentPage) => Math.max(prevCurrentPage - 1, 1))
  }

  const handlePageChange = (page: number) => {
    setCurrentPage(page)
  }

  if (loading) {
    return <div>Loading...</div>
  }

  if (error) {
    return <div>Error: {error}</div>
  }

  return (
    <div className="mx-auto w-full sm:w-[650px] md:w-[850px] lg:w-[700px] xl:w-[800px] 2xl:w-[1400px]">
      <div className="w my-2">
        <Input
          type="text"
          placeholder="Search by title"
          className="w-full border-b border-gray-300 bg-transparent text-typography transition duration-300 ease-in-out focus:outline-none dark:text-typography"
          value={searchQuery}
          onChange={(e) => setSearchQuery(e.target.value)}
        />
      </div>
      <div className="sm:w-[650px] md:w-[850px] lg:w-[700px] xl:w-[800px] 2xl:w-[1400px]">
        {currentItems.map((songCardInfo, index) => (
          <div
            key={index}
            className="mb-2 rounded-sm bg-subsectionbackgroundcolor p-2 shadow-lg"
          >
            <SongCard
              {...songCardInfo}
              isFavorite={playerFavoriteSongs.some(
                (favSong) => favSong.songId === songCardInfo.songId
              )}
            />
          </div>
        ))}
      </div>
      <div className="flex justify-around ">
        <div className="rounded-md py-2">
          <NavigationButtons
            currentPage={currentPage}
            totalPages={totalPages}
            onPageChange={handlePageChange}
            onNext={handleNext}
            onPrevious={handlePrevious}
          />
        </div>
      </div>
    </div>
  )
}

export default SongCardList
