import { toast } from "react-toastify";

const BASE_OPTIONS = {
  credentials: "include",
};

const BASE_URL = process.env.NEXT_PUBLIC_ARTEMIS_API_URL;

if (!BASE_URL) {
  throw new Error("Cannot run -- no NEXT_PUBLIC_ARTEMIS_API_URL provided?");
}

export function ToApiUrl(url: string) {
  if (url[0] === "/") {
    url = url.substring(1)
  }
  
  return `${BASE_URL}/${url}`;
}

export type ApiFetchReturn<T> = {
  body: T,
  statusCode: number;
}

export async function ApiFetch<T = unknown>(
  url: string,
  options: RequestInit = {},
  displaySuccess = false,
  displayFailure = false,
): Promise<ApiFetchReturn<T>> {
  const mergedOptions = Object.assign({}, BASE_OPTIONS, options);
  
  try {
    const res = await fetch(ToApiUrl(url), mergedOptions);
    
    // Some endpoints don't return JSON.
    const rt = await res.text();
    const rj = (rt[0] === "{" || rt[0] === "[") ? JSON.parse(rt) : null;
    
    if (!res.ok) {
      const errorMessage = rj?.message ?? rj?.error ?? rt;

      console.warn(errorMessage);

      if (displayFailure) {
        toast.error(errorMessage, {
          className: "error-toast",
          bodyClassName: "toast-body",
          closeButton: false,
          theme: "colored",
        });
      }
    }

    if (res.ok && displaySuccess && rj?.message) {
      toast.success(rj.message, {
        className: "success-toast",
        bodyClassName: "toast-body",
        closeButton: false,
        theme: "colored",
      })
    }

    return { body: rj ?? rt, statusCode: res.status };
  } catch (err) {
    console.error(err);
    throw err;
  }
}
  